@@ -283,7 +283,10 @@ class App(object):
                 raise NotFound
             return wrapper
         
-        cfg_module = obj_from_str(self.cfg_module)
+        try:
+            cfg_module = obj_from_str(self.cfg_module)
+        except ImportError:
+            cfg_module = None
         if cfg_module:
             for k in cfg_module.__dict__.keys():
                 if not k.startswith('__') and k.isupper():
